pub struct BurnInstructionArgs {
pub amount: u64,
}Fields
amount: u64Trait Implementations
Sourceimpl BorshDeserialize for BurnInstructionArgswhere
u64: BorshDeserialize,
impl BorshDeserialize for BurnInstructionArgswhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for BurnInstructionArgswhere
u64: BorshSerialize,
impl BorshSerialize for BurnInstructionArgswhere
u64: BorshSerialize,
Sourceimpl Clone for BurnInstructionArgs
impl Clone for BurnInstructionArgs
Sourcefn clone(&self) -> BurnInstructionArgs
fn clone(&self) -> BurnInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BurnInstructionArgs
impl Debug for BurnInstructionArgs
Sourceimpl PartialEq for BurnInstructionArgs
impl PartialEq for BurnInstructionArgs
Sourcefn eq(&self, other: &BurnInstructionArgs) -> bool
fn eq(&self, other: &BurnInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BurnInstructionArgs
impl StructuralPartialEq for BurnInstructionArgs