pub struct CloseRateAccountCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for CloseRateAccount via CPI.
Accounts:
[]mint[]verification_config_or_mint_authority[]instructions_sysvar_or_creator[writable]rate_account[writable]destination[]mint_from[]mint_to
Implementations
Sourceimpl<'a, 'b> CloseRateAccountCpiBuilder<'a, 'b>
impl<'a, 'b> CloseRateAccountCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn mint(&mut self, mint: &'b AccountInfo<'a>) -> &mut Self
pub fn instructions_sysvar_or_creator( &mut self, instructions_sysvar_or_creator: &'b AccountInfo<'a>, ) -> &mut Self
pub fn rate_account(&mut self, rate_account: &'b AccountInfo<'a>) -> &mut Self
pub fn destination(&mut self, destination: &'b AccountInfo<'a>) -> &mut Self
pub fn mint_from(&mut self, mint_from: &'b AccountInfo<'a>) -> &mut Self
pub fn mint_to(&mut self, mint_to: &'b AccountInfo<'a>) -> &mut Self
pub fn close_rate_args(&mut self, close_rate_args: CloseRateArgs) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult