pub struct CloseRateAccountInstructionArgs {
pub close_rate_args: CloseRateArgs,
}Fields
close_rate_args: CloseRateArgsTrait Implementations
Sourceimpl BorshDeserialize for CloseRateAccountInstructionArgswhere
CloseRateArgs: BorshDeserialize,
impl BorshDeserialize for CloseRateAccountInstructionArgswhere
CloseRateArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CloseRateAccountInstructionArgs
impl Clone for CloseRateAccountInstructionArgs
Sourcefn clone(&self) -> CloseRateAccountInstructionArgs
fn clone(&self) -> CloseRateAccountInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CloseRateAccountInstructionArgs
impl PartialEq for CloseRateAccountInstructionArgs
Sourcefn eq(&self, other: &CloseRateAccountInstructionArgs) -> bool
fn eq(&self, other: &CloseRateAccountInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CloseRateAccountInstructionArgs
impl StructuralPartialEq for CloseRateAccountInstructionArgs