pub struct ConvertCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for Convert via CPI.
Accounts:
[]mint[]verification_config[]instructions_sysvar[]mint_authority[]permanent_delegate[writable, signer]payer[writable]mint_from[writable]mint_to[writable]token_account_from[writable]token_account_to[]rate_account[writable]receipt_account[]token_program[]system_program
Implementations
Sourceimpl<'a, 'b> ConvertCpiBuilder<'a, 'b>
impl<'a, 'b> ConvertCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn mint(&mut self, mint: &'b AccountInfo<'a>) -> &mut Self
pub fn verification_config( &mut self, verification_config: &'b AccountInfo<'a>, ) -> &mut Self
pub fn instructions_sysvar( &mut self, instructions_sysvar: &'b AccountInfo<'a>, ) -> &mut Self
pub fn permanent_delegate( &mut self, permanent_delegate: &'b AccountInfo<'a>, ) -> &mut Self
pub fn payer(&mut self, payer: &'b AccountInfo<'a>) -> &mut Self
pub fn mint_from(&mut self, mint_from: &'b AccountInfo<'a>) -> &mut Self
pub fn mint_to(&mut self, mint_to: &'b AccountInfo<'a>) -> &mut Self
pub fn token_account_from( &mut self, token_account_from: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_account_to( &mut self, token_account_to: &'b AccountInfo<'a>, ) -> &mut Self
pub fn rate_account(&mut self, rate_account: &'b AccountInfo<'a>) -> &mut Self
pub fn receipt_account( &mut self, receipt_account: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_program(&mut self, token_program: &'b AccountInfo<'a>) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn convert_args(&mut self, convert_args: ConvertArgs) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult