pub struct CreateDistributionEscrowCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for CreateDistributionEscrow via CPI.
Accounts:
[]mint[]verification_config_or_mint_authority[]instructions_sysvar_or_creator[]distribution_escrow_authority[writable, signer]payer[writable]distribution_token_account[]distribution_mint[]token_program[]associated_token_account_program[]system_program
Implementations
Sourceimpl<'a, 'b> CreateDistributionEscrowCpiBuilder<'a, 'b>
impl<'a, 'b> CreateDistributionEscrowCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn mint(&mut self, mint: &'b AccountInfo<'a>) -> &mut Self
pub fn instructions_sysvar_or_creator( &mut self, instructions_sysvar_or_creator: &'b AccountInfo<'a>, ) -> &mut Self
pub fn payer(&mut self, payer: &'b AccountInfo<'a>) -> &mut Self
pub fn distribution_token_account( &mut self, distribution_token_account: &'b AccountInfo<'a>, ) -> &mut Self
pub fn distribution_mint( &mut self, distribution_mint: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_program(&mut self, token_program: &'b AccountInfo<'a>) -> &mut Self
pub fn associated_token_account_program( &mut self, associated_token_account_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn create_distribution_escrow_args( &mut self, create_distribution_escrow_args: CreateDistributionEscrowArgs, ) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult