pub struct CreateDistributionEscrowInstructionArgs {
pub create_distribution_escrow_args: CreateDistributionEscrowArgs,
}Fields
create_distribution_escrow_args: CreateDistributionEscrowArgsTrait Implementations
Sourceimpl BorshDeserialize for CreateDistributionEscrowInstructionArgs
impl BorshDeserialize for CreateDistributionEscrowInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateDistributionEscrowInstructionArgs
impl Clone for CreateDistributionEscrowInstructionArgs
Sourcefn clone(&self) -> CreateDistributionEscrowInstructionArgs
fn clone(&self) -> CreateDistributionEscrowInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreateDistributionEscrowInstructionArgs
impl PartialEq for CreateDistributionEscrowInstructionArgs
Sourcefn eq(&self, other: &CreateDistributionEscrowInstructionArgs) -> bool
fn eq(&self, other: &CreateDistributionEscrowInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateDistributionEscrowInstructionArgs
impl StructuralPartialEq for CreateDistributionEscrowInstructionArgs