pub struct CreateProofAccountInstructionArgs {
pub create_proof_args: CreateProofArgs,
}Fields
create_proof_args: CreateProofArgsTrait Implementations
Sourceimpl BorshDeserialize for CreateProofAccountInstructionArgswhere
CreateProofArgs: BorshDeserialize,
impl BorshDeserialize for CreateProofAccountInstructionArgswhere
CreateProofArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateProofAccountInstructionArgswhere
CreateProofArgs: BorshSerialize,
impl BorshSerialize for CreateProofAccountInstructionArgswhere
CreateProofArgs: BorshSerialize,
Sourceimpl Clone for CreateProofAccountInstructionArgs
impl Clone for CreateProofAccountInstructionArgs
Sourcefn clone(&self) -> CreateProofAccountInstructionArgs
fn clone(&self) -> CreateProofAccountInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreateProofAccountInstructionArgs
impl PartialEq for CreateProofAccountInstructionArgs
Sourcefn eq(&self, other: &CreateProofAccountInstructionArgs) -> bool
fn eq(&self, other: &CreateProofAccountInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateProofAccountInstructionArgs
impl StructuralPartialEq for CreateProofAccountInstructionArgs