pub struct CreateRateAccountInstructionArgs {
pub create_rate_args: CreateRateArgs,
}Fields
create_rate_args: CreateRateArgsTrait Implementations
Sourceimpl BorshDeserialize for CreateRateAccountInstructionArgswhere
CreateRateArgs: BorshDeserialize,
impl BorshDeserialize for CreateRateAccountInstructionArgswhere
CreateRateArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateRateAccountInstructionArgswhere
CreateRateArgs: BorshSerialize,
impl BorshSerialize for CreateRateAccountInstructionArgswhere
CreateRateArgs: BorshSerialize,
Sourceimpl Clone for CreateRateAccountInstructionArgs
impl Clone for CreateRateAccountInstructionArgs
Sourcefn clone(&self) -> CreateRateAccountInstructionArgs
fn clone(&self) -> CreateRateAccountInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreateRateAccountInstructionArgs
impl PartialEq for CreateRateAccountInstructionArgs
Sourcefn eq(&self, other: &CreateRateAccountInstructionArgs) -> bool
fn eq(&self, other: &CreateRateAccountInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateRateAccountInstructionArgs
impl StructuralPartialEq for CreateRateAccountInstructionArgs