pub struct MintInstructionArgs {
pub amount: u64,
}Fields
amount: u64Trait Implementations
Sourceimpl BorshDeserialize for MintInstructionArgswhere
u64: BorshDeserialize,
impl BorshDeserialize for MintInstructionArgswhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MintInstructionArgswhere
u64: BorshSerialize,
impl BorshSerialize for MintInstructionArgswhere
u64: BorshSerialize,
Sourceimpl Clone for MintInstructionArgs
impl Clone for MintInstructionArgs
Sourcefn clone(&self) -> MintInstructionArgs
fn clone(&self) -> MintInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MintInstructionArgs
impl Debug for MintInstructionArgs
Sourceimpl PartialEq for MintInstructionArgs
impl PartialEq for MintInstructionArgs
Sourcefn eq(&self, other: &MintInstructionArgs) -> bool
fn eq(&self, other: &MintInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MintInstructionArgs
impl StructuralPartialEq for MintInstructionArgs