pub struct SplitInstructionArgs {
pub split_args: SplitArgs,
}Fields
split_args: SplitArgsTrait Implementations
Sourceimpl BorshDeserialize for SplitInstructionArgswhere
SplitArgs: BorshDeserialize,
impl BorshDeserialize for SplitInstructionArgswhere
SplitArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SplitInstructionArgswhere
SplitArgs: BorshSerialize,
impl BorshSerialize for SplitInstructionArgswhere
SplitArgs: BorshSerialize,
Sourceimpl Clone for SplitInstructionArgs
impl Clone for SplitInstructionArgs
Sourcefn clone(&self) -> SplitInstructionArgs
fn clone(&self) -> SplitInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SplitInstructionArgs
impl Debug for SplitInstructionArgs
Sourceimpl PartialEq for SplitInstructionArgs
impl PartialEq for SplitInstructionArgs
Sourcefn eq(&self, other: &SplitInstructionArgs) -> bool
fn eq(&self, other: &SplitInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SplitInstructionArgs
impl StructuralPartialEq for SplitInstructionArgs