pub struct UpdateDefaultAccountStateInstructionArgs {
pub update_default_account_state_args: UpdateDefaultAccountStateArgs,
}Fields
update_default_account_state_args: UpdateDefaultAccountStateArgsTrait Implementations
Sourceimpl BorshDeserialize for UpdateDefaultAccountStateInstructionArgs
impl BorshDeserialize for UpdateDefaultAccountStateInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateDefaultAccountStateInstructionArgs
impl Clone for UpdateDefaultAccountStateInstructionArgs
Sourcefn clone(&self) -> UpdateDefaultAccountStateInstructionArgs
fn clone(&self) -> UpdateDefaultAccountStateInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for UpdateDefaultAccountStateInstructionArgs
impl PartialEq for UpdateDefaultAccountStateInstructionArgs
Sourcefn eq(&self, other: &UpdateDefaultAccountStateInstructionArgs) -> bool
fn eq(&self, other: &UpdateDefaultAccountStateInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateDefaultAccountStateInstructionArgs
impl StructuralPartialEq for UpdateDefaultAccountStateInstructionArgs