pub struct UpdateMetadataInstructionArgs {
pub update_metadata_args: UpdateMetadataArgs,
}Fields
update_metadata_args: UpdateMetadataArgsTrait Implementations
Sourceimpl BorshDeserialize for UpdateMetadataInstructionArgswhere
UpdateMetadataArgs: BorshDeserialize,
impl BorshDeserialize for UpdateMetadataInstructionArgswhere
UpdateMetadataArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateMetadataInstructionArgswhere
UpdateMetadataArgs: BorshSerialize,
impl BorshSerialize for UpdateMetadataInstructionArgswhere
UpdateMetadataArgs: BorshSerialize,
Sourceimpl Clone for UpdateMetadataInstructionArgs
impl Clone for UpdateMetadataInstructionArgs
Sourcefn clone(&self) -> UpdateMetadataInstructionArgs
fn clone(&self) -> UpdateMetadataInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for UpdateMetadataInstructionArgs
impl PartialEq for UpdateMetadataInstructionArgs
Sourcefn eq(&self, other: &UpdateMetadataInstructionArgs) -> bool
fn eq(&self, other: &UpdateMetadataInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateMetadataInstructionArgs
impl StructuralPartialEq for UpdateMetadataInstructionArgs