pub struct UpdateProofAccountInstructionArgs {
pub update_proof_args: UpdateProofArgs,
}Fields
update_proof_args: UpdateProofArgsTrait Implementations
Sourceimpl BorshDeserialize for UpdateProofAccountInstructionArgswhere
UpdateProofArgs: BorshDeserialize,
impl BorshDeserialize for UpdateProofAccountInstructionArgswhere
UpdateProofArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateProofAccountInstructionArgswhere
UpdateProofArgs: BorshSerialize,
impl BorshSerialize for UpdateProofAccountInstructionArgswhere
UpdateProofArgs: BorshSerialize,
Sourceimpl Clone for UpdateProofAccountInstructionArgs
impl Clone for UpdateProofAccountInstructionArgs
Sourcefn clone(&self) -> UpdateProofAccountInstructionArgs
fn clone(&self) -> UpdateProofAccountInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for UpdateProofAccountInstructionArgs
impl PartialEq for UpdateProofAccountInstructionArgs
Sourcefn eq(&self, other: &UpdateProofAccountInstructionArgs) -> bool
fn eq(&self, other: &UpdateProofAccountInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateProofAccountInstructionArgs
impl StructuralPartialEq for UpdateProofAccountInstructionArgs