pub struct UpdateRateAccountInstructionArgs {
pub update_rate_args: UpdateRateArgs,
}Fields
update_rate_args: UpdateRateArgsTrait Implementations
Sourceimpl BorshDeserialize for UpdateRateAccountInstructionArgswhere
UpdateRateArgs: BorshDeserialize,
impl BorshDeserialize for UpdateRateAccountInstructionArgswhere
UpdateRateArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateRateAccountInstructionArgswhere
UpdateRateArgs: BorshSerialize,
impl BorshSerialize for UpdateRateAccountInstructionArgswhere
UpdateRateArgs: BorshSerialize,
Sourceimpl Clone for UpdateRateAccountInstructionArgs
impl Clone for UpdateRateAccountInstructionArgs
Sourcefn clone(&self) -> UpdateRateAccountInstructionArgs
fn clone(&self) -> UpdateRateAccountInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for UpdateRateAccountInstructionArgs
impl PartialEq for UpdateRateAccountInstructionArgs
Sourcefn eq(&self, other: &UpdateRateAccountInstructionArgs) -> bool
fn eq(&self, other: &UpdateRateAccountInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateRateAccountInstructionArgs
impl StructuralPartialEq for UpdateRateAccountInstructionArgs