pub struct UpdateVerificationConfigInstructionArgs {
pub update_verification_config_args: UpdateVerificationConfigArgs,
}Fields
update_verification_config_args: UpdateVerificationConfigArgsTrait Implementations
Sourceimpl BorshDeserialize for UpdateVerificationConfigInstructionArgs
impl BorshDeserialize for UpdateVerificationConfigInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateVerificationConfigInstructionArgs
impl Clone for UpdateVerificationConfigInstructionArgs
Sourcefn clone(&self) -> UpdateVerificationConfigInstructionArgs
fn clone(&self) -> UpdateVerificationConfigInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for UpdateVerificationConfigInstructionArgs
impl PartialEq for UpdateVerificationConfigInstructionArgs
Sourcefn eq(&self, other: &UpdateVerificationConfigInstructionArgs) -> bool
fn eq(&self, other: &UpdateVerificationConfigInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateVerificationConfigInstructionArgs
impl StructuralPartialEq for UpdateVerificationConfigInstructionArgs