pub struct VerifyInstructionArgs {
pub verify_args: VerifyArgs,
}Fields
verify_args: VerifyArgsTrait Implementations
Sourceimpl BorshDeserialize for VerifyInstructionArgswhere
VerifyArgs: BorshDeserialize,
impl BorshDeserialize for VerifyInstructionArgswhere
VerifyArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for VerifyInstructionArgswhere
VerifyArgs: BorshSerialize,
impl BorshSerialize for VerifyInstructionArgswhere
VerifyArgs: BorshSerialize,
Sourceimpl Clone for VerifyInstructionArgs
impl Clone for VerifyInstructionArgs
Sourcefn clone(&self) -> VerifyInstructionArgs
fn clone(&self) -> VerifyInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifyInstructionArgs
impl Debug for VerifyInstructionArgs
Sourceimpl PartialEq for VerifyInstructionArgs
impl PartialEq for VerifyInstructionArgs
Sourcefn eq(&self, other: &VerifyInstructionArgs) -> bool
fn eq(&self, other: &VerifyInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for VerifyInstructionArgs
impl StructuralPartialEq for VerifyInstructionArgs