pub struct CloseActionReceiptArgs {
pub action_id: u64,
pub token_account: Pubkey,
}Fields
action_id: u64token_account: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for CloseActionReceiptArgs
impl BorshDeserialize for CloseActionReceiptArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CloseActionReceiptArgs
impl Clone for CloseActionReceiptArgs
Sourcefn clone(&self) -> CloseActionReceiptArgs
fn clone(&self) -> CloseActionReceiptArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CloseActionReceiptArgs
impl Debug for CloseActionReceiptArgs
Sourceimpl PartialEq for CloseActionReceiptArgs
impl PartialEq for CloseActionReceiptArgs
Sourcefn eq(&self, other: &CloseActionReceiptArgs) -> bool
fn eq(&self, other: &CloseActionReceiptArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CloseActionReceiptArgs
impl StructuralPartialEq for CloseActionReceiptArgs