pub struct CloseClaimReceiptArgs {
pub action_id: u64,
pub merkle_proof: Option<Vec<[u8; 32]>>,
}Fields
action_id: u64merkle_proof: Option<Vec<[u8; 32]>>Trait Implementations
Sourceimpl BorshDeserialize for CloseClaimReceiptArgs
impl BorshDeserialize for CloseClaimReceiptArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CloseClaimReceiptArgs
impl Clone for CloseClaimReceiptArgs
Sourcefn clone(&self) -> CloseClaimReceiptArgs
fn clone(&self) -> CloseClaimReceiptArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CloseClaimReceiptArgs
impl Debug for CloseClaimReceiptArgs
Sourceimpl PartialEq for CloseClaimReceiptArgs
impl PartialEq for CloseClaimReceiptArgs
Sourcefn eq(&self, other: &CloseClaimReceiptArgs) -> bool
fn eq(&self, other: &CloseClaimReceiptArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CloseClaimReceiptArgs
impl StructuralPartialEq for CloseClaimReceiptArgs