pub struct CloseRateArgs {
pub action_id: u64,
}Fields
action_id: u64Trait Implementations
Sourceimpl BorshDeserialize for CloseRateArgswhere
u64: BorshDeserialize,
impl BorshDeserialize for CloseRateArgswhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CloseRateArgswhere
u64: BorshSerialize,
impl BorshSerialize for CloseRateArgswhere
u64: BorshSerialize,
Sourceimpl Clone for CloseRateArgs
impl Clone for CloseRateArgs
Sourcefn clone(&self) -> CloseRateArgs
fn clone(&self) -> CloseRateArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CloseRateArgs
impl Debug for CloseRateArgs
Sourceimpl PartialEq for CloseRateArgs
impl PartialEq for CloseRateArgs
Sourcefn eq(&self, other: &CloseRateArgs) -> bool
fn eq(&self, other: &CloseRateArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CloseRateArgs
impl StructuralPartialEq for CloseRateArgs