pub struct ConvertArgs {
pub action_id: u64,
pub amount_to_convert: u64,
}Fields
action_id: u64amount_to_convert: u64Trait Implementations
Sourceimpl BorshDeserialize for ConvertArgswhere
u64: BorshDeserialize,
impl BorshDeserialize for ConvertArgswhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ConvertArgswhere
u64: BorshSerialize,
impl BorshSerialize for ConvertArgswhere
u64: BorshSerialize,
Sourceimpl Clone for ConvertArgs
impl Clone for ConvertArgs
Sourcefn clone(&self) -> ConvertArgs
fn clone(&self) -> ConvertArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConvertArgs
impl Debug for ConvertArgs
Sourceimpl PartialEq for ConvertArgs
impl PartialEq for ConvertArgs
Sourcefn eq(&self, other: &ConvertArgs) -> bool
fn eq(&self, other: &ConvertArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ConvertArgs
impl StructuralPartialEq for ConvertArgs