pub struct CreateDistributionEscrowArgs {
pub action_id: u64,
pub merkle_root: [u8; 32],
}Fields
action_id: u64merkle_root: [u8; 32]Trait Implementations
Sourceimpl BorshDeserialize for CreateDistributionEscrowArgs
impl BorshDeserialize for CreateDistributionEscrowArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateDistributionEscrowArgs
impl Clone for CreateDistributionEscrowArgs
Sourcefn clone(&self) -> CreateDistributionEscrowArgs
fn clone(&self) -> CreateDistributionEscrowArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateDistributionEscrowArgs
impl Debug for CreateDistributionEscrowArgs
Sourceimpl PartialEq for CreateDistributionEscrowArgs
impl PartialEq for CreateDistributionEscrowArgs
Sourcefn eq(&self, other: &CreateDistributionEscrowArgs) -> bool
fn eq(&self, other: &CreateDistributionEscrowArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateDistributionEscrowArgs
impl StructuralPartialEq for CreateDistributionEscrowArgs