pub struct CreateProofArgs {
pub action_id: u64,
pub data: Vec<[u8; 32]>,
}Fields
action_id: u64data: Vec<[u8; 32]>Trait Implementations
Sourceimpl BorshDeserialize for CreateProofArgs
impl BorshDeserialize for CreateProofArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateProofArgs
impl BorshSerialize for CreateProofArgs
Sourceimpl Clone for CreateProofArgs
impl Clone for CreateProofArgs
Sourcefn clone(&self) -> CreateProofArgs
fn clone(&self) -> CreateProofArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateProofArgs
impl Debug for CreateProofArgs
Sourceimpl PartialEq for CreateProofArgs
impl PartialEq for CreateProofArgs
Sourcefn eq(&self, other: &CreateProofArgs) -> bool
fn eq(&self, other: &CreateProofArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateProofArgs
impl StructuralPartialEq for CreateProofArgs