pub struct MetadataPointerArgs {
pub authority: Pubkey,
pub metadata_address: Pubkey,
}Fields
metadata_address: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for MetadataPointerArgswhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for MetadataPointerArgswhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MetadataPointerArgswhere
Pubkey: BorshSerialize,
impl BorshSerialize for MetadataPointerArgswhere
Pubkey: BorshSerialize,
Sourceimpl Clone for MetadataPointerArgs
impl Clone for MetadataPointerArgs
Sourcefn clone(&self) -> MetadataPointerArgs
fn clone(&self) -> MetadataPointerArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataPointerArgs
impl Debug for MetadataPointerArgs
Sourceimpl PartialEq for MetadataPointerArgs
impl PartialEq for MetadataPointerArgs
Sourcefn eq(&self, other: &MetadataPointerArgs) -> bool
fn eq(&self, other: &MetadataPointerArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MetadataPointerArgs
impl StructuralPartialEq for MetadataPointerArgs