pub struct MintArgs {
pub decimals: u8,
pub mint_authority: Pubkey,
pub freeze_authority: Pubkey,
}Fields
decimals: u8Trait Implementations
Sourceimpl BorshDeserialize for MintArgs
impl BorshDeserialize for MintArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MintArgs
impl BorshSerialize for MintArgs
impl Eq for MintArgs
impl StructuralPartialEq for MintArgs