pub struct RateConfig {
pub rounding: u8,
pub numerator: u8,
pub denominator: u8,
}Fields
rounding: u8numerator: u8denominator: u8Trait Implementations
Sourceimpl BorshDeserialize for RateConfigwhere
u8: BorshDeserialize,
impl BorshDeserialize for RateConfigwhere
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RateConfigwhere
u8: BorshSerialize,
impl BorshSerialize for RateConfigwhere
u8: BorshSerialize,
Sourceimpl Clone for RateConfig
impl Clone for RateConfig
Sourcefn clone(&self) -> RateConfig
fn clone(&self) -> RateConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateConfig
impl Debug for RateConfig
Sourceimpl PartialEq for RateConfig
impl PartialEq for RateConfig
Sourcefn eq(&self, other: &RateConfig) -> bool
fn eq(&self, other: &RateConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RateConfig
impl StructuralPartialEq for RateConfig