pub struct ScaledUiAmountConfigArgs {
pub authority: Pubkey,
pub multiplier: [u8; 8],
pub new_multiplier_effective_timestamp: i64,
pub new_multiplier: [u8; 8],
}Fields
multiplier: [u8; 8]new_multiplier_effective_timestamp: i64new_multiplier: [u8; 8]Trait Implementations
Sourceimpl BorshDeserialize for ScaledUiAmountConfigArgs
impl BorshDeserialize for ScaledUiAmountConfigArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for ScaledUiAmountConfigArgs
impl Clone for ScaledUiAmountConfigArgs
Sourcefn clone(&self) -> ScaledUiAmountConfigArgs
fn clone(&self) -> ScaledUiAmountConfigArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScaledUiAmountConfigArgs
impl Debug for ScaledUiAmountConfigArgs
Sourceimpl PartialEq for ScaledUiAmountConfigArgs
impl PartialEq for ScaledUiAmountConfigArgs
Sourcefn eq(&self, other: &ScaledUiAmountConfigArgs) -> bool
fn eq(&self, other: &ScaledUiAmountConfigArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ScaledUiAmountConfigArgs
impl StructuralPartialEq for ScaledUiAmountConfigArgs