pub struct SplitArgs {
pub action_id: u64,
}Fields
action_id: u64Trait Implementations
Sourceimpl BorshDeserialize for SplitArgswhere
u64: BorshDeserialize,
impl BorshDeserialize for SplitArgswhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SplitArgswhere
u64: BorshSerialize,
impl BorshSerialize for SplitArgswhere
u64: BorshSerialize,
impl Eq for SplitArgs
impl StructuralPartialEq for SplitArgs