pub struct TrimVerificationConfigArgs {
pub instruction_discriminator: u8,
pub size: u8,
pub close: bool,
}Fields
instruction_discriminator: u8size: u8close: boolTrait Implementations
Sourceimpl BorshDeserialize for TrimVerificationConfigArgs
impl BorshDeserialize for TrimVerificationConfigArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for TrimVerificationConfigArgs
impl Clone for TrimVerificationConfigArgs
Sourcefn clone(&self) -> TrimVerificationConfigArgs
fn clone(&self) -> TrimVerificationConfigArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrimVerificationConfigArgs
impl Debug for TrimVerificationConfigArgs
Sourceimpl PartialEq for TrimVerificationConfigArgs
impl PartialEq for TrimVerificationConfigArgs
Sourcefn eq(&self, other: &TrimVerificationConfigArgs) -> bool
fn eq(&self, other: &TrimVerificationConfigArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for TrimVerificationConfigArgs
impl StructuralPartialEq for TrimVerificationConfigArgs