pub struct UpdateDefaultAccountStateArgs {
pub state: u8,
}Fields
state: u8Trait Implementations
Sourceimpl BorshDeserialize for UpdateDefaultAccountStateArgswhere
u8: BorshDeserialize,
impl BorshDeserialize for UpdateDefaultAccountStateArgswhere
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateDefaultAccountStateArgswhere
u8: BorshSerialize,
impl BorshSerialize for UpdateDefaultAccountStateArgswhere
u8: BorshSerialize,
Sourceimpl Clone for UpdateDefaultAccountStateArgs
impl Clone for UpdateDefaultAccountStateArgs
Sourcefn clone(&self) -> UpdateDefaultAccountStateArgs
fn clone(&self) -> UpdateDefaultAccountStateArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for UpdateDefaultAccountStateArgs
impl PartialEq for UpdateDefaultAccountStateArgs
Sourcefn eq(&self, other: &UpdateDefaultAccountStateArgs) -> bool
fn eq(&self, other: &UpdateDefaultAccountStateArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateDefaultAccountStateArgs
impl StructuralPartialEq for UpdateDefaultAccountStateArgs