pub struct UpdateMetadataArgs {
pub metadata: TokenMetadataArgs,
}Fields
metadata: TokenMetadataArgsTrait Implementations
Sourceimpl BorshDeserialize for UpdateMetadataArgswhere
TokenMetadataArgs: BorshDeserialize,
impl BorshDeserialize for UpdateMetadataArgswhere
TokenMetadataArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateMetadataArgswhere
TokenMetadataArgs: BorshSerialize,
impl BorshSerialize for UpdateMetadataArgswhere
TokenMetadataArgs: BorshSerialize,
Sourceimpl Clone for UpdateMetadataArgs
impl Clone for UpdateMetadataArgs
Sourcefn clone(&self) -> UpdateMetadataArgs
fn clone(&self) -> UpdateMetadataArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateMetadataArgs
impl Debug for UpdateMetadataArgs
Sourceimpl PartialEq for UpdateMetadataArgs
impl PartialEq for UpdateMetadataArgs
Sourcefn eq(&self, other: &UpdateMetadataArgs) -> bool
fn eq(&self, other: &UpdateMetadataArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateMetadataArgs
impl StructuralPartialEq for UpdateMetadataArgs