pub struct UpdateProofArgs {
pub action_id: u64,
pub data: [u8; 32],
pub offset: u32,
}Fields
action_id: u64data: [u8; 32]offset: u32Trait Implementations
Sourceimpl BorshDeserialize for UpdateProofArgs
impl BorshDeserialize for UpdateProofArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateProofArgs
impl BorshSerialize for UpdateProofArgs
Sourceimpl Clone for UpdateProofArgs
impl Clone for UpdateProofArgs
Sourcefn clone(&self) -> UpdateProofArgs
fn clone(&self) -> UpdateProofArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateProofArgs
impl Debug for UpdateProofArgs
Sourceimpl PartialEq for UpdateProofArgs
impl PartialEq for UpdateProofArgs
Sourcefn eq(&self, other: &UpdateProofArgs) -> bool
fn eq(&self, other: &UpdateProofArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateProofArgs
impl StructuralPartialEq for UpdateProofArgs