pub struct UpdateRateArgs {
pub action_id: u64,
pub rate: RateConfig,
}Fields
action_id: u64rate: RateConfigTrait Implementations
Sourceimpl BorshDeserialize for UpdateRateArgs
impl BorshDeserialize for UpdateRateArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateRateArgs
impl BorshSerialize for UpdateRateArgs
Sourceimpl Clone for UpdateRateArgs
impl Clone for UpdateRateArgs
Sourcefn clone(&self) -> UpdateRateArgs
fn clone(&self) -> UpdateRateArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateRateArgs
impl Debug for UpdateRateArgs
Sourceimpl PartialEq for UpdateRateArgs
impl PartialEq for UpdateRateArgs
Sourcefn eq(&self, other: &UpdateRateArgs) -> bool
fn eq(&self, other: &UpdateRateArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateRateArgs
impl StructuralPartialEq for UpdateRateArgs