pub struct UpdateVerificationConfigArgs {
pub instruction_discriminator: u8,
pub cpi_mode: bool,
pub offset: u8,
pub program_addresses: Vec<Pubkey>,
}Fields
instruction_discriminator: u8cpi_mode: booloffset: u8program_addresses: Vec<Pubkey>Trait Implementations
Sourceimpl BorshDeserialize for UpdateVerificationConfigArgs
impl BorshDeserialize for UpdateVerificationConfigArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateVerificationConfigArgs
impl Clone for UpdateVerificationConfigArgs
Sourcefn clone(&self) -> UpdateVerificationConfigArgs
fn clone(&self) -> UpdateVerificationConfigArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateVerificationConfigArgs
impl Debug for UpdateVerificationConfigArgs
Sourceimpl PartialEq for UpdateVerificationConfigArgs
impl PartialEq for UpdateVerificationConfigArgs
Sourcefn eq(&self, other: &UpdateVerificationConfigArgs) -> bool
fn eq(&self, other: &UpdateVerificationConfigArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateVerificationConfigArgs
impl StructuralPartialEq for UpdateVerificationConfigArgs