pub struct VerifyArgs {
pub ix: u8,
pub instruction_data: Vec<u8>,
}Fields
ix: u8instruction_data: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for VerifyArgs
impl BorshDeserialize for VerifyArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for VerifyArgs
impl BorshSerialize for VerifyArgs
Sourceimpl Clone for VerifyArgs
impl Clone for VerifyArgs
Sourcefn clone(&self) -> VerifyArgs
fn clone(&self) -> VerifyArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifyArgs
impl Debug for VerifyArgs
Sourceimpl PartialEq for VerifyArgs
impl PartialEq for VerifyArgs
Sourcefn eq(&self, other: &VerifyArgs) -> bool
fn eq(&self, other: &VerifyArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for VerifyArgs
impl StructuralPartialEq for VerifyArgs